#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Mar 27 13:59:57 2023

@author: anton
"""

from SLiCAP import *

fileName     = "dynamicTransferReceiver"
specFileName = "specifications.csv"


# import the specifications
specs = csv2specs(specFileName)

i1 = instruction()
i1.setCircuit(fileName + ".cir")
# Define the circuit parameters from the specifications
specs2circuit(specs, i1)

htmlPage("Circuit Data")
head2html("Circuit diagram")
img2html(fileName + ".svg", 600)
netlist2html(fileName + ".cir")
elementData2html(i1.circuit)
params2html(i1.circuit)

specs.append(
            specItem(
                "GB_R",
                description = "Minimum GB product of receiver OpAmp.",
                value    = sp.N(1/sp.pi/i1.getParValue("A_R")/2),
                units       = 'Hz',
                specType    = "design",
            )
        )

# Determination of minimum value A_0,
# We will evaluate this from the servo function with GB ==> oo


i1.setSource("V1")
i1.setDetector("V_out")
i1.setLGref("E1")
i1.setSimType("numeric")
i1.setDataType("laplace")
i1.setGainType('servo')
Srv = sp.limit(i1.execute().laplace, sp.Symbol('GB'), 'oo')

gain, numerCoeffs, denomCoeffs = coeffsTransfer(Srv)
order                          = len(denomCoeffs) - 1
omegaLow                       = denomCoeffs[0]/denomCoeffs[-1]
A0min = sp.solve( omegaLow - (2*sp.pi*i1.getParValue('f_min')**(1/order)))[0]
specs.append(
            specItem(
                "A0_R",
                description = "Minimum DC gain of receiver OpAmp.",
                value    = A0min,
                units       = '',
                specType    = "design",
            )
        )
# Save the specifications and display the specifications on a html page.
htmlPage("Updated specifications")
# Save the specifications
specs2csv(specs, "specifications.csv")
# Display them on an HTML page
specs2html(specs)
