#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Mar 27 13:59:57 2023

@author: anton
"""

from SLiCAP import *

fileName     = "dynamicTransferTransmitter"
specFileName = "specifications.csv"

# import the specifications
specs = csv2specs(specFileName)

i1 = instruction()
i1.setCircuit(fileName + ".cir")
# Define the circuit parameters from the specifications
specs2circuit(specs, i1)

htmlPage("Circuit Data")
head2html("Circuit diagram")
img2html(fileName + ".svg", 600)
netlist2html(fileName + ".cir")
elementData2html(i1.circuit)
params2html(i1.circuit)

i1.setSource("V1")
i1.setDetector("V_out")
i1.setLGref("E1")
i1.setSimType("numeric")
i1.setGainType("loopgain")
i1.setDataType("laplace")

loopgain = i1.execute().laplace

DCgain, numerCoeffs, denomCoeffs = coeffsTransfer(loopgain)

orderNumer = len(numerCoeffs) - 1
orderDenom  = len(denomCoeffs) - 1

LP_product  = (-(DCgain * numerCoeffs[-1] / denomCoeffs[-1]))

GB = sp.solve(LP_product - 4*sp.pi**2*i1.getParValue('f_max')**(orderDenom - orderNumer), sp.Symbol('GB') )[0]

specs.append(
            specItem(
                "GB_T",
                description = "Minimum GB product of transmitter OpAmp.",
                value    = GB,
                units       = 'Hz',
                specType    = "design",
            )
        )

# Save the specifications and display the specifications on a html page.
htmlPage("Updated specifications")
# Save the specifications
specs2csv(specs, "specifications.csv")
# Display them on an HTML page
specs2html(specs)